import React, { useState, useEffect } from 'react';
import { Link, useLocation } from "react-router-dom"; // Import useLocation
import { Helmet } from 'react-helmet-async'; // Import Helmet
import { createPageUrl } from "@/utils";
import { Menu, X, Linkedin, Github, Mail, Globe, Twitter, ArrowRight, Sun, Moon } from "lucide-react"; // Added Sun, Moon
import { motion } from "framer-motion";
import { Button } from "@/features/shared/components/ui/button";
import { siteConfig } from "@/features/shared/components/config/siteConfig";
import { useTheme } from "@/context/ThemeProvider"; // Added useTheme import

// --- JSON-LD Schema Definitions ---
const websiteSchema = {
  "@context": "https://schema.org",
  "@type": "WebSite",
  "url": "https://www.chenmagled.com", // Updated to use www prefix
  "name": siteConfig.name,
  "potentialAction": {
    "@type": "SearchAction",
    "target": "https://chenmagled.com/search?q={search_term_string}", // Placeholder
    "query-input": "required name=search_term_string"
  }
};

const personSchema = {
  "@context": "https://schema.org",
  "@type": "Person",
  "name": siteConfig.name,
  "jobTitle": siteConfig.role,
  "url": "https://www.chenmagled.com", // Updated to use www prefix
  "sameAs": [
    siteConfig.social.linkedin,
    siteConfig.social.github,
    siteConfig.social.twitter,
    siteConfig.social.instagram
  ].filter(Boolean) // Filter out potential null/undefined values
};
// --- End JSON-LD Schema Definitions ---


export default function Layout({ children, currentPageName, onLinkHover }) {
  const [mobileMenuOpen, setMobileMenuOpen] = useState(false);
  const [scrolled, setScrolled] = useState(false);
  const { theme, toggleTheme } = useTheme(); // Added theme hook
  const location = useLocation(); // Get location object
  const isHomePage = location.pathname === '/'; // Check if it's the homepage
 
  // Removed useEffect that forced dark theme

  useEffect(() => {
    const handleScroll = () => {
      setScrolled(window.scrollY > 20);
    };
    window.addEventListener('scroll', handleScroll);
    return () => window.removeEventListener('scroll', handleScroll);
  }, []);

  useEffect(() => {
    window.scrollTo(0, 0);
  }, [currentPageName]);

  // Handle preloading on hover
  const handleLinkHover = (pageName) => {
    if (onLinkHover && typeof onLinkHover === 'function') {
      onLinkHover(pageName);
    }
  };

  return (
    <div className="min-h-screen bg-[linear-gradient(to_bottom,rgb(0_102_204_/_0.05),rgb(0_102_204_/_0))] dark:bg-[rgb(2,6,23)] text-foreground"> {/* Apply gradient directly for light mode, keep specific dark override */}
      {/* Skip Navigation Link */}
      <a
        href="#main-content"
        className="sr-only focus:not-sr-only focus:absolute focus:top-4 focus:left-4 focus:z-[100] focus:px-4 focus:py-2 focus:bg-primary focus:text-primary-foreground focus:rounded-md focus:shadow-lg focus:outline-none focus:ring-2 focus:ring-ring focus:ring-offset-2 transition-all duration-200"
        onClick={(e) => {
          e.preventDefault();
          const mainContent = document.getElementById('main-content');
          if (mainContent) {
            mainContent.focus();
            mainContent.scrollIntoView({ behavior: 'smooth' });
          }
        }}
      >
        Skip to main content
      </a>
      
      {/* Add Helmet for SEO and Head Management */}
      <Helmet>
        {/* Meta tags for performance */}
        <meta http-equiv="x-dns-prefetch-control" content="on" />
        <link rel="dns-prefetch" href="//fonts.googleapis.com" />
        <link rel="dns-prefetch" href="//fonts.gstatic.com" />
        <link rel="preconnect" href="//fonts.googleapis.com" crossorigin />
        <link rel="preconnect" href="//fonts.gstatic.com" crossorigin />
        
        {/* Font loading optimization with font-display: swap */}
        <style>
          {`
            @font-face {
              font-family: 'Inter';
              font-style: normal;
              font-weight: 400 700;
              font-display: swap; /* Prevents layout shifts during font loading */
              src: url(https://fonts.gstatic.com/s/inter/v11/UcC73FwrK3iLTeHuS_fvQtMwCp50KnMa1ZL7.woff2) format('woff2');
            }
          `}
        </style>
        
        {/* Structured Data */}
        <script type="application/ld+json">
          {JSON.stringify(websiteSchema)}
        </script>
        <script type="application/ld+json">
          {JSON.stringify(personSchema)}
        </script>
      </Helmet>

      <header
        className={`fixed top-0 left-0 right-0 z-50 transition-all duration-300 ${
          scrolled ? 'bg-background/80 dark:bg-slate-900/80 backdrop-blur-md shadow-md dark:shadow-slate-900/20' : 'bg-transparent' // Adjusted for theme
        }`}
      >
        <nav className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between items-center h-16 sm:h-18">
            <Link
              to={createPageUrl("Home")}
              className="font-bold text-xl relative group"
              onMouseEnter={() => handleLinkHover("Home")}
            >
              {isHomePage ? (
                <h1 className="inline"> {/* Use h1 only on homepage */}
                  <span className="bg-clip-text text-transparent bg-gradient-to-r from-blue-400 to-purple-400">
                    {siteConfig.name}
                  </span>
                </h1>
              ) : (
                <span className="inline"> {/* Use span on other pages */}
                   <span className="bg-clip-text text-transparent bg-gradient-to-r from-blue-400 to-purple-400">
                    {siteConfig.name}
                  </span>
                </span>
              )}
            </Link>

            <div className="flex items-center gap-4 sm:gap-6">
              {/* Desktop Navigation */}
              <div className="hidden md:flex items-center space-x-6 lg:space-x-8">
                {siteConfig.navigation.map((item) => (
                  <Link
                    key={item}
                    to={createPageUrl(item)}
                    className={`text-sm font-medium transition-colors ${
                      currentPageName === item
                        ? 'text-primary dark:text-blue-400' // Adjusted for theme
                        : 'text-muted-foreground hover:text-primary dark:hover:text-blue-400' // Adjusted for theme
                    }`}
                    onMouseEnter={() => handleLinkHover(item)}
                  >
                    {item}
                  </Link>
                ))}
                {/* Theme Toggle Button (Desktop) */}
                <Button
                  variant="ghost"
                  size="icon"
                  onClick={toggleTheme}
                  aria-label={`Switch to ${theme === 'dark' ? 'light' : 'dark'} theme`}
                  className={`transition-colors ${
                    theme === 'dark'
                      ? 'text-amber-300 hover:text-amber-200 hover:bg-amber-900/20'
                      : 'text-indigo-600 hover:text-indigo-500 hover:bg-indigo-100'
                  }`}
                >
                  {/* Icon logic remains the same, styles adjusted */}
                  {theme === 'dark' ? (
                    <Sun className="h-5 w-5" aria-hidden="true" />
                  ) : (
                    <Moon className="h-5 w-5" aria-hidden="true" />
                  )}
                </Button>
              </div>

              {/* Mobile Menu Button & Theme Toggle */}
              <div className="md:hidden flex items-center gap-1">
                 {/* Theme Toggle Button (Mobile) - Proper touch target */}
                 <Button
                    variant="ghost"
                    size="icon"
                    onClick={toggleTheme}
                    aria-label={`Switch to ${theme === 'dark' ? 'light' : 'dark'} theme`}
                    className={`min-w-[44px] min-h-[44px] transition-colors ${
                      theme === 'dark'
                        ? 'text-amber-300 hover:text-amber-200 hover:bg-amber-900/20'
                        : 'text-indigo-600 hover:text-indigo-500 hover:bg-indigo-100'
                    }`}
                  >
                     {/* Icon logic remains the same, styles adjusted */}
                    {theme === 'dark' ? (
                      <Sun className="h-5 w-5" aria-hidden="true" />
                    ) : (
                      <Moon className="h-5 w-5" aria-hidden="true" />
                    )}
                  </Button>
                 {/* Mobile Menu Button - Proper touch target */}
                <Button
                  onClick={() => setMobileMenuOpen(!mobileMenuOpen)}
                  variant="ghost"
                  size="icon"
                  className="min-w-[44px] min-h-[44px] text-muted-foreground hover:text-foreground"
                  aria-label="Toggle menu"
                >
                  {mobileMenuOpen ? (
                    <X className="h-6 w-6" />
                  ) : (
                    <Menu className="h-6 w-6" />
                  )}
                </Button>
              </div>
            </div>
          </div>

          {/* Mobile Navigation - Enhanced for better mobile UX */}
          {mobileMenuOpen && (
            <motion.div
              initial={{ opacity: 0, y: -20 }}
              animate={{ opacity: 1, y: 0 }}
              exit={{ opacity: 0, y: -20 }}
              className="md:hidden py-2 bg-background/95 dark:bg-slate-900/95 backdrop-blur-md border-b border-border shadow-lg"
            >
              {siteConfig.navigation.map((item) => (
                <Link
                  key={item}
                  to={createPageUrl(item)}
                  className={`block py-4 px-6 text-base font-medium transition-colors min-h-[44px] flex items-center ${
                    currentPageName === item
                      ? 'text-primary dark:text-blue-400 bg-primary/5 dark:bg-blue-400/10'
                      : 'text-muted-foreground hover:text-primary dark:hover:text-blue-400 hover:bg-muted/50'
                  }`}
                  onClick={() => setMobileMenuOpen(false)}
                  onMouseEnter={() => handleLinkHover(item)}
                >
                  {item}
                </Link>
              ))}
            </motion.div>
          )}
        </nav>
      </header>

      {/* Main Content */}
      <main id="main-content" tabIndex="-1" className="pt-16 outline-none">
        <div className="max-w-7xl mx-auto">
          {children}
        </div>
      </main>
 
      {/* Footer */}
      <footer className="mt-20 relative overflow-hidden bg-slate-50 dark:bg-[rgb(2,6,23)]">
        {/* Top decorative border */}
        <div className="absolute top-0 left-0 w-full h-[1px]">
          {/* Gradient border for both light and dark modes */}
          <div className="h-full bg-gradient-to-r from-transparent via-primary/40 dark:via-blue-500/40 to-transparent"></div>
        </div>
 
        {/* Footer background */}
        <div className="relative">
          {/* Decorative elements with light mode support */}
          <div className="absolute inset-0 overflow-hidden pointer-events-none">
            {/* Set fixed dimensions and prevent layout shifts */}
            <div
              className="absolute -top-[300px] -right-[200px] w-[500px] h-[500px] rounded-full bg-blue-100/50 dark:bg-blue-500/5 blur-3xl transform-gpu will-change-transform"
              style={{ width: '500px', height: '500px' }}
            ></div>
            <div
              className="absolute -bottom-[300px] -left-[200px] w-[500px] h-[500px] rounded-full bg-purple-100/50 dark:bg-purple-500/5 blur-3xl transform-gpu will-change-transform"
              style={{ width: '500px', height: '500px' }}
            ></div>
            {/* Light mode pattern with fixed size */}
            <div className="absolute inset-0 bg-grid-slate-200/50 [mask-image:linear-gradient(to_bottom,transparent,black,transparent)] dark:bg-grid-slate-700/25 hidden sm:block transform-gpu"></div>
          </div>

          {/* Main footer content */}
          <div className="max-w-7xl mx-auto py-16 px-4 sm:px-6 lg:px-8 relative">
            <div className="grid grid-cols-1 md:grid-cols-12 gap-12 pb-12">
              {/* Logo and description column - span 5 columns on desktop */}
              <div className="md:col-span-5 space-y-8">
                <Link 
                  to={createPageUrl("Home")} 
                  className="inline-block relative transition-transform hover:scale-105"
                >
                  <span className="font-bold text-2xl bg-clip-text text-transparent bg-gradient-to-r from-blue-400 to-purple-400 min-h-[2rem]">
                    {siteConfig.name}
                  </span>
                </Link>
 
                {/* Enhanced card for light mode */}
                <div className="max-w-md p-6 rounded-xl border border-slate-200 shadow-sm bg-white/80 dark:border-gray-700 dark:bg-slate-800/20 backdrop-blur-sm min-h-[120px]">
                  <p className="text-slate-700 dark:text-gray-300 leading-relaxed">
                    {siteConfig.role} based in {siteConfig.location}. Specializing in cloud solutions, full-stack development, and AI integration.
                  </p>
                </div>
 
                {/* Social links - Enhanced for light mode */}
                <div className="flex flex-wrap gap-3">
                  <a
                    href={siteConfig.social.linkedin}
                    target="_blank" 
                    rel="noopener noreferrer"
                    aria-label="LinkedIn profile"
                    className="transform transition-transform hover:scale-110"
                  >
                    <div className="w-10 h-10 rounded-xl flex items-center justify-center bg-blue-100 shadow-sm dark:shadow-none dark:bg-[#0A66C2]/20">
                      <Linkedin className="h-5 w-5 text-blue-700 dark:text-[#0A66C2]/90" />
                      <span className="sr-only">Connect with me on LinkedIn</span>
                    </div>
                  </a>
                  <a
                    href={siteConfig.social.github}
                    target="_blank" 
                    rel="noopener noreferrer"
                    aria-label="GitHub profile"
                    className="transform transition-transform hover:scale-110"
                  >
                    <div className="w-10 h-10 rounded-xl flex items-center justify-center bg-slate-100 shadow-sm dark:shadow-none dark:bg-slate-700/60">
                      <Github className="h-5 w-5 text-slate-700 dark:text-white" />
                      <span className="sr-only">View my projects on GitHub</span>
                    </div>
                  </a>
                  <a
                    href={siteConfig.social.twitter}
                    target="_blank" 
                    rel="noopener noreferrer"
                    aria-label="Twitter profile"
                    className="transform transition-transform hover:scale-110"
                  >
                    <div className="w-10 h-10 rounded-xl flex items-center justify-center bg-sky-100 shadow-sm dark:shadow-none dark:bg-[#1DA1F2]/20">
                      <Twitter className="h-5 w-5 text-sky-600 dark:text-[#1DA1F2]/90" />
                      <span className="sr-only">Follow me on Twitter</span>
                    </div>
                  </a>
                  <a
                    href={`mailto:${siteConfig.email}`}
                    aria-label="Email"
                    className="transform transition-transform hover:scale-110"
                  >
                    <div className="w-10 h-10 rounded-xl flex items-center justify-center bg-primary/10 shadow-sm dark:shadow-none dark:bg-blue-600/20">
                      <Mail className="h-5 w-5 text-primary dark:text-blue-400" />
                      <span className="sr-only">Contact me via email</span>
                    </div>
                  </a>
                </div>
              </div>
              
              {/* Navigation and contact columns */}
              <div className="md:col-span-7">
                <div className="grid grid-cols-1 sm:grid-cols-2 gap-8">
                  {/* Quick links column - Enhanced for light mode */}
                  <div className="p-6 rounded-xl border border-slate-200 shadow-sm bg-white/80 dark:border-gray-700 dark:bg-slate-800/20 backdrop-blur-sm min-h-[250px]">
                    <h3 className="font-bold text-lg mb-4 text-slate-800 dark:text-white flex items-center">
                      <span className="inline-block w-2 h-2 mr-2 bg-primary dark:bg-blue-400 rounded-full"></span>
                      Navigation
                    </h3>

                    <nav className="space-y-3">
                      {siteConfig.navigation.map((item) => (
                        <Link
                          key={item}
                          to={createPageUrl(item)} 
                          className={`block group flex items-center transition-colors
                            ${
                              currentPageName === item ?
                                'font-medium text-primary dark:text-blue-400' :
                                'text-slate-600 hover:text-primary dark:text-gray-300 dark:hover:text-blue-400'
                            }
                          `}
                        >
                          <ArrowRight className={`w-4 h-4 mr-2 transition-all transform ${
                            currentPageName === item ?
                              'opacity-100 text-primary dark:text-blue-400' :
                              'opacity-0 group-hover:opacity-100 group-hover:translate-x-1 text-primary/70 dark:text-blue-400/70'
                          }`} />
                          {item}
                        </Link>
                      ))}
                    </nav>
                  </div>

                  {/* Contact info column - Enhanced for light mode */}
                  <div className="p-6 rounded-xl border border-slate-200 shadow-sm bg-white/80 dark:border-gray-700 dark:bg-slate-800/20 backdrop-blur-sm min-h-[250px]">
                    <h3 className="font-bold text-lg mb-4 text-slate-800 dark:text-white flex items-center">
                      <span className="inline-block w-2 h-2 mr-2 bg-purple-500 dark:bg-purple-400 rounded-full"></span>
                      Contact
                    </h3>

                    <ul className="space-y-4">
                      <li className="group">
                        <a
                          href={`mailto:${siteConfig.email}`}
                          className="flex items-start transition-colors text-slate-600 hover:text-primary dark:text-gray-300 dark:hover:text-blue-400"
                        >
                          <div className="mt-1 mr-3 p-1.5 rounded-lg bg-primary/10 dark:bg-blue-500/20 group-hover:bg-primary/20 dark:group-hover:bg-blue-500/30 transition-colors">
                            <Mail className="w-4 h-4 text-primary dark:text-blue-400" />
                          </div>
                          <div>
                            <p className="text-xs text-slate-500 dark:text-gray-400">Email</p>
                            <p className="text-slate-700 group-hover:text-primary dark:text-gray-300 dark:group-hover:text-blue-400 transition-colors">
                              {siteConfig.email}
                            </p>
                          </div>
                        </a>
                      </li>

                      <li className="group">
                        <div className="flex items-start">
                          <div className="mt-1 mr-3 p-1.5 rounded-lg bg-purple-100 dark:bg-purple-500/20 transition-colors">
                            <Globe className="w-4 h-4 text-purple-600 dark:text-purple-400" />
                          </div>
                          <div>
                            <p className="text-xs text-slate-500 dark:text-gray-400">Location</p>
                            <p className="text-slate-700 dark:text-gray-300 transition-colors">
                              {siteConfig.location}
                            </p>
                          </div>
                        </div>
                      </li>
                    </ul>
                  </div>
                </div>
              </div>
            </div>

            {/* Copyright bar - Enhanced for light mode */}
            <div className="border-t border-slate-200 dark:border-gray-800 pt-8 text-center text-sm">
              <p className="text-slate-500 dark:text-gray-400">
                &copy; {new Date().getFullYear()} {siteConfig.name}. All rights reserved.
              </p>
            </div>
          </div>
        </div>
      </footer>
    </div>
  );
}

